From e3539134f94b55130f378b3c6a5c51e2d69765e1 Mon Sep 17 00:00:00 2001
From: Eric Kooistra <kooistra@astron.nl>
Date: Fri, 25 Mar 2022 16:29:09 +0100
Subject: [PATCH] Support 20b FIR coefficients.

---
 applications/lofar2/model/pfs_coeff_final.m | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/applications/lofar2/model/pfs_coeff_final.m b/applications/lofar2/model/pfs_coeff_final.m
index f05ee7528d..406d474461 100644
--- a/applications/lofar2/model/pfs_coeff_final.m
+++ b/applications/lofar2/model/pfs_coeff_final.m
@@ -97,8 +97,8 @@
 % h) Support loading and analysing LOFAR1 coefficients for comparison
 % i) Support changing the half power subband band width via relative_bw = 1
 % j) Save plots in plots/
 % k) Create FIR coefficients for 16b or 18b Kaiser (has sharp band edge) and
 %    Hanning (has almost flat DC response for all poly phases)
 
 close all;
 clear all;
@@ -121,6 +121,7 @@ if not(reproduce_ftf)
     % word size for coefficients
     nof_bits = 16;
     nof_bits = 18;
+    nof_bits = 20;
     % window function for coefficients
     kaiser_beta = 1;
     use_window = 'Kaiser';
@@ -97,8 +97,8 @@
 % i) Support changing the half power subband band width via relative_bw = 1
 % j) Save plots in plots/
-% k) Create FIR coefficients for 16b or 18b Kaiser (has sharp band edge) and
-%    Hanning (has almost flat DC response for all poly phases)
+% k) Create FIR coefficients for 16b, 18b, 20b Kaiser (has sharp band edge)
+%    and Hanning (has almost flat DC response for all poly phases)
 
 close all;
-- 
GitLab